=== modified file 'bzrlib/merge.py'
--- bzrlib/merge.py	2006-02-27 20:48:40 +0000
+++ bzrlib/merge.py	2006-03-06 17:47:48 +0000
@@ -835,6 +835,7 @@
     merger.backup_files = backup_files
     merger.merge_type = merge_type
     merger.interesting_ids = interesting_ids
+    merger.ignore_zero = ignore_zero
     if interesting_files:
         assert not interesting_ids, ('Only supply interesting_ids'
                                      ' or interesting_files')

=== modified file 'bzrlib/tests/test_merge.py'
--- bzrlib/tests/test_merge.py	2006-02-20 09:50:27 +0000
+++ bzrlib/tests/test_merge.py	2006-03-06 17:47:48 +0000
@@ -1,13 +1,15 @@
 import os
+from StringIO import StringIO
 
 from bzrlib.branch import Branch
 from bzrlib.builtins import merge
 from bzrlib.commit import commit
 from bzrlib.errors import UnrelatedBranches, NoCommits, BzrCommandError
-from bzrlib.merge import transform_tree
+from bzrlib.merge import transform_tree, merge_inner
 from bzrlib.osutils import pathjoin
 from bzrlib.revision import common_ancestor
 from bzrlib.tests import TestCaseWithTransport
+from bzrlib.trace import (enable_test_log, disable_test_log)
 from bzrlib.workingtree import WorkingTree
 
 
@@ -79,3 +81,21 @@
         tree.rename_one(filename, filename2)
         tree.rename_one('dirname1', 'dirname2')
         transform_tree(tree, tree.branch.basis_tree())
+
+    def test_ignore_zero_merge_inner(self):
+        # Test that merge_inner's ignore zero paramter is effective
+        tree_a =self.make_branch_and_tree('a')
+        tree_a.commit(message="hello")
+        dir_b = tree_a.bzrdir.sprout('b')
+        tree_b = dir_b.open_workingtree()
+        tree_a.commit(message="hello again")
+        log = StringIO()
+        merge_inner(tree_b.branch, tree_a, tree_b.basis_tree(), 
+                    this_tree=tree_b, ignore_zero=True)
+        lines = self._get_log().splitlines(True)[-1]
+        self.failUnless('All changes applied successfully.\n' not in lines)
+        tree_b.revert([])
+        merge_inner(tree_b.branch, tree_a, tree_b.basis_tree(), 
+                    this_tree=tree_b, ignore_zero=False)
+        lines = self._get_log().splitlines(True)[-1]
+        self.failUnless('All changes applied successfully.\n' in lines)

